pub struct NaiveDateTimeWithoutYear<C: ParseContext> {
pub context: C,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
}Fields
context: Cmonth: u8day: u8hour: u8minute: u8second: u8Implementations
Sourceimpl<C: ParseContext> NaiveDateTimeWithoutYear<C>
impl<C: ParseContext> NaiveDateTimeWithoutYear<C>
pub fn with_year(self, year: i32) -> Result<NaiveDateTime, ParseError<C>>
pub fn into_naive_date_time(self) -> Result<NaiveDateTime, ParseError<C>>
Sourcepub fn compare<C2: ParseContext>(
&self,
other: &NaiveDateTimeWithoutYear<C2>,
) -> Ordering
pub fn compare<C2: ParseContext>( &self, other: &NaiveDateTimeWithoutYear<C2>, ) -> Ordering
Whether self come before or after other or is the same,
assuming the same year and that the dates are valid for that
assumed year. NaiveDateTimeWithoutYear is not implementing
Ord / PartialOrd because those also require PartialEq and it’s
unclear whether that should include position or not, also
ordering is easily misunderstood, too, since year is actually
unknown.